package com.example.fieldagent.data.apis

import com.example.fieldagent.data.models.responses.*

import com.example.fieldagent.data.network.responseUtil.ApiResponse
import okhttp3.RequestBody
import retrofit2.Call
import retrofit2.http.*

interface WebService {
    companion object {

        private const val LOGIN = "auth/login"
        private const val INSPECTIONS = "inspections"
        private const val DAMAGES = "Damages"
        private const val RESTROOM_LIST = "restroom-conditions"
        private const val ITEM_LIST = "combined-list"
        private const val CATEGORY = "categories"
        private const val SELECT_CATEGORY = "categories"
        private const val SUB_CATEGORY = "subcategories"
        private const val PREFERENCES = "/api/master/preferences"
        private const val UPDATE_NUMBER = "/api/update-phone"
        private const val VERIFY_OTP = "/api/verify-otp"
        private const val RESEND_OTP = "api/resend-otp"
        private const val REGISTER = "/api/register"
        private const val FORGOT_PASSWORD = "/api/forgot_password"
        private const val CHANGE_PASSWORD = "/api/password-change"
        private const val PROFILE_UPDATE = "/api/profile-update"
        private const val LOGOUT = "/api/app_logout"
        private const val SEND_SMS = "/api/send-sms"
        private const val SEND_EMAIL_OTP = "/api/send-email-otp"
        private const val EMAIL_VERIFY = "/api/email-verify"
        private const val UPDATE_FCM_ID = "/api/update-fcm-id"
        private const val CREATE_REQUEST = "/api/create-request"
        private const val CONFIRM_REQUEST = "/api/confirm-request"
        private const val ADD_CARD = "api/add-card"
        private const val UPDATE_CARD = "/api/update-card"
        private const val DELETE_CARD = "/api/delete-card"
        private const val ADD_MONEY = "/api/add-money"
        private const val ADD_REVIEW = "/api/add-review"
        private const val REQUEST_USER_APPROVE = "/api/request-user-approve"
        private const val COMPLETE_CHAT = "/api/complete-chat"
        private const val UPLOAD_IMAGE = "/api/upload-image"
        private const val FEEDS = "/api/feeds"
        private const val FEEDS_COMMENTS = "/api/feeds/comments/{feed_id}"
        private const val VIEW_FEEDS = "/api/feeds/view/{feed_id}"
        private const val ADD_FAVORITE = "/api/feeds/add-favorite/{feed_id}"
        private const val ADD_LIKE = "/api/feeds/add-like/{feed_id}"
        private const val ADD_COMMENT = "/api/feeds/add-comment/{feed_id}"

        private const val REQUESTS = "/api/requests-cs"
        private const val REQUEST_DETAIL = "/api/request-detail"
        private const val HOME = "/api/home"
        private const val CANCEL_REQUEST = "/api/cancel-request"
        private const val DOCTOR_LIST = "/api/doctor-list"
        private const val BANNERS = "/api/banners"
        private const val COUPONS = "/api/coupons"
        private const val DOCTOR_DETAIL = "/api/doctor-detail"
        private const val REVIEW_LIST = "/api/review-list"
        private const val WALLET_HISTORY = "/api/wallet-history"
        private const val CARD_LISTING = "/api/cards"
        private const val WALLET = "/api/wallet"
        private const val REQUEST_CHECK = "/api/request-check"
        private const val CHAT_LISTING = "/api/chat-listing"
        private const val CHAT_MESSAGES = "/api/chat-messages"
        private const val NOTIFICATIONS = "/api/notifications"
        private const val CATEGORIES = "/api/categories"
        private const val CLASSES = "/api/classes"
        private const val CLASS_DETAIL = "/api/class/detail"
        private const val ENROLL_USER = "/api/enroll-user"
        private const val CLASS_JOIN = "/api/class/join"
        private const val ORDER_CREATE = "/api/order/create"
        private const val HYPER_PAY_COMPLETE_DONE = "api/webhook/hyperpay"
        private const val RAZOR_PAY_WEBHOOK = "/api/razor-pay-webhook"
        private const val SERVICES = "/api/services"
        private const val GET_FILTERS = "/api/get-filters"
        private const val GET_SLOTS = "/api/get-slots"
        private const val CALL_STATUS = "/api/call-status"
        private const val PAGES = "/api/pages"
        private const val PACK_SUB = "/api/pack-sub"
        private const val PURCHASE_PACK = "/api/sub-pack"
        private const val PACK_DETAIL = "/api/pack-detail"
        private const val SUBSCRIPTIONS = "/api/subscriptions"
        private const val SUBSCRIPTION_DETAIL = "/api/subscription-detail"
        private const val SUBSCRIPTION_PACK = "/api/subscription-pack"
        private const val ASK_QUESTIONS = "/api/ask-questions"
        private const val ASK_QUESTIONS_DETAIL = "/api/ask-question-detail"
        private const val WATER_LIMIT = "/api/water-limit"
        private const val PROTEIN_LIMIT = "/api/protein-limit"
        private const val DRINK_WATER = "/api/drink-water"
        private const val DRINK_PROTEIN = "/api/drink-protein"
        private const val ADD_FAMILY = "/api/add-family"
        private const val SYMPTOM = "/api/symptoms"
        private const val UPDATE_SYMPTOM = "/api/update-request-symptoms"
        private const val EXTRA_PAYMENT = "/api/pay-extra-payment"
        private const val CARE_PLANS = "/api/care-plans"
        private const val TIERS = "/api/tiers"
        private const val ADD_BANK = "/api/add-bank"
        private const val BANK_ACCOUNTS = "/api/bank-accounts"
        private const val GET_MEDICAL_HISTORY = "/api/get-medical-history"

        private const val DIRECTIONS = "https://maps.googleapis.com/maps/api/directions/json"

        private const val WORKING_HOURS = "/api/workingHours"
        private const val SPEAKOUT_LIST = "/common/listSpeakouts"

        /*V2 Api*/
        private const val CREATE_REQUEST_V2 = "/api/v2/create-request"
        private const val CONFIRM_REQUEST_V2 = "/api/v2/confirm-request"
        private const val DOCTOR_LIST_V2 = "/api/v2/doctor-list"
        private const val CANCEL_REQUEST_V2 = "/api/v2/cancel-request"

        private const val CONTACT_LIST = "/api/contact-list"
        private const val CONTACT_ADD = "/api/contact-add"
        private const val CONTACT_DELETE = "/api/contact-delete"
        private const val CONTACT_MESSAGE = "/api/contact-message"

    }

    /*POST APIS*/
    @FormUrlEncoded
    @POST(LOGIN)
    fun login(@FieldMap hashMap: HashMap<String, Any>): Call<UserData>


    @GET(INSPECTIONS)
    fun inspectionsList(@QueryMap hashMap: Map<String, String>): Call<InspectionData>


    @Multipart
    @POST(INSPECTIONS)
    fun createInspections(@PartMap map: HashMap<String, RequestBody>): Call<SimpleResponseData>


    @GET(INSPECTIONS)
    fun damagesList(@QueryMap hashMap: Map<String, String>): Call<InspectionData>




    @Multipart
    @POST(DAMAGES)
    fun createDamage(@PartMap map: HashMap<String, RequestBody>): Call<SimpleResponseData>


    @DELETE("$INSPECTIONS/{id}")
    fun deleteInspections(@Path("id") id: String): Call<SimpleResponseData>

    @PUT("$INSPECTIONS/{id}")
    fun updateInspection(@Path("id") id: String): Call<ApiResponse<UserData>>


    @DELETE("$DAMAGES/{id}")
    fun deleteDamage(@Path("id") id: String): Call<SimpleResponseData>

    @PUT("$DAMAGES/{id}")
    fun updateDamage(@Path("id") id: String): Call<ApiResponse<UserData>>


    @GET(RESTROOM_LIST)
    fun getRoomsList(): Call<RoomConditionData>

    @GET(CATEGORY)
    fun getCategoryList(): Call<ItemList>

    @GET(SELECT_CATEGORY)
    fun getSelectCategoryList(@QueryMap hashMap: Map<String, String>): Call<ItemList>

    @GET(SUB_CATEGORY)
    fun getSubCategoryList(@QueryMap hashMap: Map<String, String>): Call<ItemList>
    /*
        @FormUrlEncoded
        @POST(APP_VERSION)
        fun appVersion(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<AppVersion>>

        @FormUrlEncoded
        @POST(UPDATE_NUMBER)
        fun updateNumber(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<UserData>>

        @FormUrlEncoded
        @POST(VERIFY_OTP)
        fun verifyOtp(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<UserData>>

        @FormUrlEncoded
        @POST(RESEND_OTP)
        fun resendOtp(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<UserData>>

        @FormUrlEncoded
        @POST(REGISTER)
        fun register(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<UserData>>

        @FormUrlEncoded
        @POST(FORGOT_PASSWORD)
        fun forgotPassword(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<UserData>>

        @FormUrlEncoded
        @POST(CHANGE_PASSWORD)
        fun changePassword(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<UserData>>

        @FormUrlEncoded
        @POST(PROFILE_UPDATE)
        fun updateProfile(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<UserData>>

        @FormUrlEncoded
        @POST(COMPLETE_CHAT)
        fun completeChat(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(SEND_SMS)
        fun sendSMS(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<UserData>>

        @FormUrlEncoded
        @POST(SEND_EMAIL_OTP)
        fun sendEmailOtp(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<UserData>>

        @FormUrlEncoded
        @POST(EMAIL_VERIFY)
        fun emailVerify(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<UserData>>

        @POST(LOGOUT)
        fun logout(): Call<ApiResponse<UserData>>

        @FormUrlEncoded
        @POST(UPDATE_FCM_ID)
        fun updateFcmId(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<UserData>>

        @POST(CREATE_REQUEST)
        fun createRequest(@Body createRequest: CreateRequest): Call<ApiResponse<CommonDataModel>>

        @POST(CREATE_REQUEST_V2)
        fun createRequestV2(@Body createRequest: CreateRequest): Call<ApiResponse<CommonDataModel>>

        @POST(CONFIRM_REQUEST)
        fun confirmRequest(@Body createRequest: CreateRequest): Call<ApiResponse<CommonDataModel>>

        @POST(CONFIRM_REQUEST_V2)
        fun confirmRequestV2(@Body createRequest: CreateRequest): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(ADD_CARD)
        fun addCard(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(UPDATE_CARD)
        fun updateCard(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(DELETE_CARD)
        fun deleteCard(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(ADD_MONEY)
        fun addMoney(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<CommonDataModel>>

        @Multipart
        @POST(UPLOAD_IMAGE)
        fun uploadFile(@PartMap map: HashMap<String, RequestBody>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(ADD_REVIEW)
        fun addReview(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<Any>>

        @FormUrlEncoded
        @POST(REQUEST_USER_APPROVE)
        fun approveWorkingHour(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<Any>>

        @FormUrlEncoded
        @POST(ENROLL_USER)
        fun enrollUser(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(CLASS_JOIN)
        fun joinClass(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(ORDER_CREATE)
        fun orderCreate(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<CommonDataModel>>


        @FormUrlEncoded
        @POST(HYPER_PAY_COMPLETE_DONE)
        fun hyperPayCompleteTrans(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<Any>>

        @FormUrlEncoded
        @POST(CANCEL_REQUEST_V2)
        fun cancelRequest(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(CALL_STATUS)
        fun callStatus(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<CommonDataModel>>

        @GET(PACK_DETAIL)
        fun packDetail(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

        @GET(SUBSCRIPTION_DETAIL)
        fun subscriptionDetail(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(PURCHASE_PACK)
        fun purchasePack(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(SUBSCRIPTION_PACK)
        fun subscriptionPack(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(ADD_FAVORITE)
        fun addFavorite(@Path("feed_id") feed_id: String,
                        @FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(ADD_LIKE)
        fun addLike(@Path("feed_id") feed_id: String,
                    @FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(ADD_COMMENT)
        fun addComment(@Path("feed_id") feed_id: String,
                       @FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(RAZOR_PAY_WEBHOOK)
        fun razorPayWebhook(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(ASK_QUESTIONS)
        fun askQuestion(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(WATER_LIMIT)
        fun setDailyLimit(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<WaterIntake>>

        @FormUrlEncoded
        @POST(PROTEIN_LIMIT)
        fun setProteinDailyLimit(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<WaterIntake>>

        @FormUrlEncoded
        @POST(DRINK_WATER)
        fun setWaterIntake(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<WaterIntake>>

        @FormUrlEncoded
        @POST(DRINK_PROTEIN)
        fun setProteinIntake(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<WaterIntake>>


        @FormUrlEncoded
        @POST(ADD_FAMILY)
        fun addFamily(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<CommonDataModel>>

        @POST(UPDATE_SYMPTOM)
        fun updateSymptom(@Body updateSymptom: UpdateSymptom): Call<ApiResponse<CommonDataModel>>

        @POST(CARE_PLANS)
        fun carePlans(@Body updateSymptom: UpdateSymptom): Call<ApiResponse<CommonDataModel>>

        @FormUrlEncoded
        @POST(ADD_BANK)
        fun addBank(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<CommonDataModel>>


        *//*GET*//*

    @GET(CLIENT_DETAILS)
    fun clientDetails(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<AppVersion>>

    @GET(COUNTRY_DATA)
    fun countryData(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(PREFERENCES)
    fun preferences(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(HOME)
    fun home(): Call<ApiResponse<CommonDataModel>>

    @GET(REQUESTS)
    fun request(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(REQUEST_DETAIL)
    fun requestDetail(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(DOCTOR_LIST)
    fun doctorList(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(DOCTOR_LIST_V2)
    fun doctorListV2(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(BANNERS)
    fun banners(): Call<ApiResponse<CommonDataModel>>

    @GET(DOCTOR_DETAIL)
    fun doctorDetails(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(REVIEW_LIST)
    fun reviewList(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(WALLET_HISTORY)
    fun walletHistory(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(CARD_LISTING)
    fun cardListing(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(WALLET)
    fun wallet(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(CHAT_LISTING)
    fun getChatListing(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(CHAT_MESSAGES)
    fun getChatMessage(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(NOTIFICATIONS)
    fun notifications(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(FEEDS)
    fun getFeeds(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(FEEDS_COMMENTS)
    fun getFeedsComment(@Path("feed_id") feed_id: String,
                        @QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(VIEW_FEEDS)
    fun viewFeeds(@Path("feed_id") feed_id: String): Call<ApiResponse<CommonDataModel>>


    @GET(CATEGORIES)
    fun categories(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(CLASSES)
    fun classesList(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(CLASS_DETAIL)
    fun classDetail(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<ClassData>>

    @GET(GET_FILTERS)
    fun getFilters(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>


    @GET(SERVICES)
    fun services(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(GET_SLOTS)
    fun getSlots(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(PAGES)
    fun getPages(): Call<ApiResponse<CommonDataModel>>

    @GET(COUPONS)
    fun coupons(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(PACK_SUB)
    fun packSub(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(SUBSCRIPTIONS)
    fun subscriptions(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(DIRECTIONS)
    fun directions(@QueryMap hashMap: Map<String, String>): Call<Direction>

    @GET(ASK_QUESTIONS)
    fun getQuestions(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(ASK_QUESTIONS_DETAIL)
    fun getQuestionsDetails(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(WATER_LIMIT)
    fun getWaterLimit(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<WaterIntake>>

    @GET(PROTEIN_LIMIT)
    fun getProteinIntake(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<WaterIntake>>

    @GET(REQUEST_CHECK)
    fun requestCheck(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(SYMPTOM)
    fun symptom(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(TIERS)
    fun carePlanTier(): Call<ApiResponse<CommonDataModel>>

    @POST(EXTRA_PAYMENT)
    fun payExtra(@Body extraPayment: Extra_payment): Call<ApiResponse<CommonDataModel>>

    @GET(BANK_ACCOUNTS)
    fun bankAccounts(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @GET(GET_MEDICAL_HISTORY)
    fun getMedicalHistory(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>


    *//*PUT API*//*
    @FormUrlEncoded
    @PUT(WORKING_HOURS)
    fun workingHours(@FieldMap hashMap: HashMap<String, String>): Call<ApiResponse<Any>>


    @GET(CONTACT_LIST)
    fun contactList(@QueryMap hashMap: Map<String, String>): Call<ApiResponse<CommonDataModel>>

    @POST(CONTACT_ADD)
    fun addContact(@Body contactList: ContactEmergency): Call<ApiResponse<CommonDataModel>>

    @FormUrlEncoded
    @POST(CONTACT_DELETE)
    fun deletContact(@FieldMap hashMap: HashMap<String, Any>): Call<ApiResponse<CommonDataModel>>

    @POST(CONTACT_MESSAGE)
    fun sendMessage(): Call<ApiResponse<CommonDataModel>>*/

}