package com.example.fieldagent.ui.damagedetails

import android.Manifest
import android.app.Dialog
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.net.Uri
import android.os.Bundle
import android.os.Environment
import android.text.Editable
import android.text.TextWatcher
import androidx.fragment.app.Fragment
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.view.Window
import android.widget.ArrayAdapter
import android.widget.Toast
import androidx.activity.result.ActivityResultLauncher
import androidx.activity.result.contract.ActivityResultContracts
import androidx.core.content.FileProvider
import androidx.fragment.app.viewModels
import androidx.lifecycle.Observer
import androidx.navigation.fragment.findNavController
import androidx.recyclerview.widget.LinearLayoutManager
import com.consultantapp.data.network.responseUtil.Status
import com.example.fieldagent.R
import com.example.fieldagent.data.models.responses.Category
import com.example.fieldagent.data.models.responses.SubCategory
import com.example.fieldagent.data.network.ApisRespHandler
import com.example.fieldagent.databinding.FragmentDamageDetailsBinding
import com.example.fieldagent.databinding.SelectPhotoBinding
import com.example.fieldagent.ui.damagedetails.adapter.DamageDetailsAdapter
import com.example.fieldagent.utils.PrefsManager
import com.example.fieldagent.utils.dialogs.ProgressDialog
import com.example.fieldagent.utils.gone
import com.example.fieldagent.utils.isConnectedToInternet
import com.example.fieldagent.utils.showSnackBar
import com.example.fieldagent.utils.visible
import dagger.hilt.android.AndroidEntryPoint
import java.io.File
import java.text.SimpleDateFormat
import java.util.Date
import java.util.HashMap
import java.util.Locale
import javax.inject.Inject
import kotlin.collections.ArrayList


@AndroidEntryPoint
class DamageDetailsFragment : Fragment() {


    private var _binding: FragmentDamageDetailsBinding? = null

    private val binding get() = _binding!!
    private lateinit var adapter: DamageDetailsAdapter
    private  val viewModel: DamageDetailsFragmentVM by viewModels()
    private lateinit var progressDialog: ProgressDialog

    @Inject
    lateinit var prefsManager: PrefsManager
    private lateinit var cameraLauncher: ActivityResultLauncher<Uri>
    private lateinit var galleryLauncher: ActivityResultLauncher<String>
    private lateinit var permissionLauncher: ActivityResultLauncher<Array<String>>

    private var imageUri: Uri? = null
    private var imageList= ArrayList<Uri?>()

    private var categoryList=ArrayList<Category>()
    private var subCategoryList=ArrayList<SubCategory>()
    private var unitList=ArrayList<String>()


    private var inspectionId="";
    private var clickPosition=-1;
    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        _binding = FragmentDamageDetailsBinding.inflate(inflater, container, false)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)


        initialize()
        setAdapter()
        listener()
        bindObservers()



    }

    private fun initialize(){
        progressDialog = ProgressDialog(requireActivity())
        inspectionId = arguments?.getString("id").toString()
        viewModel.getCategoryList()
    }

    private  fun setAdapter()
    {
        for (i in 0 until 5) {
            imageList.add(null)  // Add empty slots (or use placeholder URIs)
        }
        adapter = DamageDetailsAdapter(imageList,this)
        binding.rvImage.layoutManager=
            LinearLayoutManager(requireActivity(), LinearLayoutManager.HORIZONTAL, false)
        binding.rvImage.adapter = adapter




    }



    private fun listener(){

        binding.ivLeft.setOnClickListener {

            findNavController().popBackStack()
        }

        // Permission launcher
        permissionLauncher = registerForActivityResult(ActivityResultContracts.RequestMultiplePermissions()) { permissions ->
            if (permissions[Manifest.permission.CAMERA] == true) {
                openCamera()
            } else {
                Toast.makeText(requireContext(), "Camera permission denied", Toast.LENGTH_SHORT).show()
            }
        }


        cameraLauncher = registerForActivityResult(ActivityResultContracts.TakePicture()) { success ->
            if (success) {
                imageUri?.let {
                    val positionToReplace = imageList.indexOfFirst { it == null }
                    if (positionToReplace != -1) {
                        imageList[positionToReplace] = imageUri
                        adapter.notifyItemChanged(positionToReplace)
                    }

                }
            }
        }

        galleryLauncher = registerForActivityResult(ActivityResultContracts.GetContent()) { uri ->
            uri?.let {

                try {

                    val positionToReplace = imageList.indexOfFirst { it == null }
                    if (positionToReplace != -1) {
                        imageList[positionToReplace] = uri
                        adapter.notifyItemChanged(positionToReplace)
                    }

                }
                catch (e:Exception)
                {
                    //
                }


            }
        }
        binding.etItemValue.addTextChangedListener(object : TextWatcher {
            private var isEditing = false

            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {}

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {}

            override fun afterTextChanged(s: Editable?) {
                if (isEditing) return

                isEditing = true

                val input = s.toString().replace(" $", "").trim()

                if (input.isNotEmpty() && input.toDoubleOrNull() != null) {
                    binding.etItemValue.setText("$ $input")
                    binding.etItemValue.setSelection(binding.etItemValue.text.length) // cursor before " m²"
                }

                isEditing = false
            }
        })
        binding.btnReport.setOnClickListener {
            when{
                binding.etItemQuantity.text.toString().isEmpty() -> {
                    binding.etItemQuantity.showSnackBar(getString(R.string.please_enter_item_quantity))
                }

                binding.etItemValue.text.toString().isEmpty() -> {
                    binding.etItemValue.showSnackBar(getString(R.string.please_enter_item_value))
                }

                imageList.isEmpty() -> {
                    binding.rvImage.showSnackBar(getString(R.string.please_upload_at_least_one_image))
                }
                isConnectedToInternet(requireActivity(), true) -> {


                }
            }

        }

        binding.autoCompleteMain.setOnItemClickListener { parent, view, position, id ->
            val selectedCategoryId = categoryList[position].id
            val hashMap = HashMap<String, String>()
            hashMap["id"] = selectedCategoryId.toString()
            viewModel.getSelectCategoryList(hashMap)

        }

        binding.autoCompleteSub.setOnItemClickListener { parent, view, position, id ->
            binding.autoCompleteUnits.setText(subCategoryList[position].unit, false)

        }

    }


    private fun bindObservers(){
        viewModel.addDamage.observe(requireActivity(), Observer {
            it ?: return@Observer
            when (it.status) {
                Status.SUCCESS -> {

                    progressDialog.setLoading(false)

                    findNavController().popBackStack()


                }
                Status.ERROR -> {
                    progressDialog.setLoading(false)
                    ApisRespHandler.handleError(it.error, requireActivity())
                }
                Status.LOADING -> {
                    progressDialog.setLoading(true)
                }
            }
        })


        viewModel.categoryList.observe(requireActivity(), Observer {
            it ?: return@Observer
            when (it.status) {
                Status.SUCCESS -> {

                    progressDialog.setLoading(false)


                    val tempData=it.data?.data

                    tempData?.categories?.let { it1 -> categoryList.addAll(it1) }

                    val categoryNames = categoryList.map { it.name }
                    val adapter = ArrayAdapter(requireActivity(), R.layout.dropdown_item, categoryNames)

                    binding.autoCompleteMain.setAdapter(adapter)

                    binding.autoCompleteMain.setOnClickListener {

                        binding.autoCompleteMain.showDropDown()
                    }


                }
                Status.ERROR -> {
                    progressDialog.setLoading(false)
                    ApisRespHandler.handleError(it.error, requireActivity())
                }
                Status.LOADING -> {
                    progressDialog.setLoading(true)
                }
            }
        })


        viewModel.selectCategoryList.observe(requireActivity(), Observer {
            it ?: return@Observer
            when (it.status) {
                Status.SUCCESS -> {

                    progressDialog.setLoading(false)


                    val tempData=it.data?.data

                    if(tempData?.subCategories!!.isNotEmpty())
                    {
                        tempData.subCategories.let { it1 -> subCategoryList.addAll(it1) }
                        binding.llUnits.visible()
                        binding.llSubItem.visible()

                        val subCategoryNames = subCategoryList.map { it.name }
                        val adapter2 = ArrayAdapter(requireActivity(), R.layout.dropdown_item, subCategoryNames)

                        binding.autoCompleteSub.setAdapter(adapter2)

                        binding.autoCompleteSub.setOnClickListener {

                            binding.autoCompleteSub.showDropDown()
                        }
                        binding.autoCompleteSub.setText(subCategoryNames.first(), false)
                        binding.autoCompleteUnits.setText(subCategoryList[0].unit, false)
                    }else{
                        binding.llUnits.gone()
                        binding.llSubItem.gone()
                    }



                }
                Status.ERROR -> {
                    progressDialog.setLoading(false)
                    ApisRespHandler.handleError(it.error, requireActivity())
                }
                Status.LOADING -> {
                    progressDialog.setLoading(true)
                }
            }
        })

    }


    private  fun showImageDialog() {
        val dialog: Dialog = Dialog(requireActivity())
        val view = SelectPhotoBinding.inflate(layoutInflater)
        dialog.requestWindowFeature(Window.FEATURE_NO_TITLE)
        dialog.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        dialog.setContentView(view.root)

        view.tvGallery.setOnClickListener {
            galleryLauncher.launch("image/*")
            dialog.dismiss()
        }


        view.tvCamera.setOnClickListener {
            permissionLauncher.launch(arrayOf(Manifest.permission.CAMERA))

            dialog.dismiss()
        }
        dialog.show()
    }


    private fun openCamera() {
        imageUri = FileProvider.getUriForFile(
            requireContext(),
            "${requireContext().packageName}.provider",
            createImageFile()
        )
        cameraLauncher.launch(imageUri!!)


    }

    private fun createImageFile(): File {
        val timeStamp = SimpleDateFormat("yyyyMMdd_HHmmss", Locale.getDefault()).format(Date())
        val fileName = "JPEG_${timeStamp}_"
        val storageDir = requireContext().getExternalFilesDir(Environment.DIRECTORY_PICTURES)
        return File.createTempFile(fileName, ".jpg", storageDir)
    }

    fun clickItem(pos: Int) {
       clickPosition=pos;
        showImageDialog()
    }
    fun removeImage(pos: Int) {
        imageList.removeAt(pos)
        adapter.notifyItemRemoved(pos)
        imageList.add(null)
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}